@@ -5,6 +5,8 @@
     Read more directive.
 
     :copyright: Copyright 2012 by Christian Jann
+    :copyright: Copyright 2011-2014 by Vlad Riscutia and contributors (see
+    CONTRIBUTORS file)
     :license: FreeBSD, see LICENSE file
 '''
 from docutils import nodes
@@ -22,5 +24,5 @@ class InsertReadMoreLink(Directive):
 
 
     def run(self):
-        return [nodes.raw("", '<a name="more"> </a>', format="html")] 
+        return [nodes.raw("", '<div id="more"> </div>', format="html")]
 
